class Voice:
    def __init__(
        self,
        channel_id,
        user_id,
        session_id,
        deaf,
        mute,
        self_deaf,
        self_mute,
        self_video,
        suppress
    ):
        self.channel_id = channel_id
        self.user_id = user_id
        self.session_id = session_id
        self.deaf = deaf
        self.mute = mute
        self.self_deaf = self_deaf
        self.self_mute = self_mute
        self.self_video = self_video
        self.suppress = suppress





class Guild:
    def __init__(
        self,
        id,
        name,
        icon,
        splash,
        discovery_splash,
        owner_id,
        region,
        afk_channel_id,
        afk_timeout,
        verification_level,
        default_message_notifications,
        explicit_content_filter,
        roles,
        emojis,
        features,
        mfa_level,
        system_channel_id,
        system_channel_flags,
        rules_channel_id,
        vanity_url_code,
        description,
        banner,
        premium_tier,
        preferred_locale,
        public_updates_channel_id,
    ):
        self.id = id
        self.name = name
        self.icon = icon
        self.splash = splash
        self.discovery_splash = discovery_splash
        self.owner_id = owner_id
        self.region = region
        self.afk_channel_id = afk_channel_id
        self.afk_timeout = afk_timeout
        self.verification_level = verification_level
        self.default_message_notifications = default_message_notifications
        self.explicit_content_filter = explicit_content_filter
        self.roles = roles
        self.emojis = emojis
        self.features = features
        self.mfa_level = mfa_level
        self.system_channel_id = system_channel_id
        self.system_channel_flags = system_channel_flags
        self.rules_channel_id = rules_channel_id
        self.vanity_url_code = vanity_url_code
        self.description = description
        self.banner = banner
        self.premium_tier = premium_tier
        self.preferred_locale = preferred_locale
        self.public_updates_channel_id = public_updates_channel_id


class Template:
    def __init__(
        self,
        code,
        name,
        description,
        usage_count,
        creator_id,
        creator,
        created_at,
        updated_at,
        source_guild_id,
        serialized_source_guild,
        is_dirty
    ):
        self.code = code
        self.name = name
        self.description = description
        self.usage_count = usage_count
        self.creator_id = creator_id
        self.creator = creator
        self.created_at = created_at
        self.updated_at = updated_at
        self.source_guild_id = source_guild_id
        self.serialized_source_guild = serialized_source_guild
        self.is_dirty = is_dirty




class EmbedFooter:
    def __init__(self, text, icon_url, proxy_icon_url) -> None:
        self.text = text
        self.icon_url = icon_url
        self.proxy_icon_url = proxy_icon_url


class EmbedField:
    def __init__(self, name, value) -> None:
        self.name = name
        self.value = value


class EmbedThumbnail:
    def __init__(self, url, proxy_url, height, width) -> None:
        self.url = url
        self.proxy_url = proxy_url
        self.height = height
        self.width = width

    
class EmbedImage:
    def __init__(self, url, proxy_url, height, width) -> None:
        self.url = url
        self.proxy_url = proxy_url
        self.height = height
        self.width = width


class EmbedVideo:
    def __init__(self, url, height, width) -> None:
        self.url = url
        self.height = height
        self.width = width


class EmbedProvider:
    def __init__(self, name, url) -> None:
        self.name = name
        self.url = url


class EmbedAuthor:
    def __init__(self, name, url, icon_url, icon_proxy_url) -> None:
        self.name = name
        self.url = url
        self.icon_url = icon_url
        self.icon_proxy_url = icon_proxy_url


class Embed:
    def __init__(
        self,
        title,
        description,
        url,
        timestamp,
        color,
        footer,
        image,
        thumbnail,
        video,
        provider,
        author,
        fields
    ):
        self.title = title
        self.description = description
        self.url = url
        self.timestamp = timestamp
        self.color = color
        self.footer = footer
        self.image = image
        self.thumbnail = thumbnail
        self.video = video
        self.provider = provider
        self.author = author
        self.fields = fields


class Webhook:
    def __init__(
        self,
        id,
        type,
        channel_id,
        name,
        avatar,
        application_id
    ):
        self.id = id
        self.type = type
        self.channel_id = channel_id
        self.name = name
        self.avatar = avatar
        self.application_id = application_id




class GuildMember:
    def __init__(
        self,
        user,
        nickname,
        roles,
        joined_at,
        is_deaf,
        is_muted,
        **kwargs
    ):
        self.user = user
        self.nickname = nickname
        self.roles = roles
        self.joined_at = joined_at
        self.is_deaf = is_deaf
        self.is_muted = is_muted

        if kwargs.get('guild_id'): self.guild_id = kwargs.get('guild_id')
        else: self.guild_id = None


from tameris.models.member import Member
from tameris.models.channel import Channel
from tameris.models.guild import Guild
from tameris.models.message import Message

class Context:
    def __init__(
        self,
        author: Member,
        message: Message,
        channel: Channel,
        guild: Guild
    ):
        self.author = author
        self.message = message
        self.channel = channel
        self.guild = guild



class Command:
    def __init__(self, bot, name):
        self.bot = bot
        self.name = name
            

    def was_invoked(self, content: str):
        if content.startswith(f'{self.bot.command_prefix}{self.name}'):
            return True
        else:
            return False


    async def run(self, context, call_arguments):
        await self.bot.send_message(f'{self.name} command works\ncommand arguments are: {call_arguments.join(" ")}', context.channel.id)


from setuptools import setup, find_packages

setup(
    name='tameris',
    version='0.0.1',
    description='A Python Discord API Wrapper based around customizability and expandability!',
    author='Tabacaru Eric',
    author_email='erick.8bld@gmail.com',
    url='https://github.com/erick-dsnk/tameris',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent'
    ],
    python_requires='>=3.5'
)


class Member:
    def __init__(
        self,
        name: str,
        discriminator: str,
        id: int,
        avatar_hash: str,
        is_verified: bool = None,
        flags: int = None,
        premium_type: int = None
    ):
        self.name = name
        self.discriminator = discriminator
        self.id = id
        self.avatar_hash = avatar_hash
        self.is_verified = is_verified
        self.flags = flags
        self.premium_type = premium_type